Searches for all Google Drive folders with the specified name and optionally removes their contents and/or the folders themselves. Useful for cleaning up scratch or export folders used by Earth Engine batch processes.
clean_drive_folders_by_name(
folder_name,
delete_folders = FALSE,
verbose = TRUE
)[mandatory] (character) Name of the folder(s) to search for in Google Drive.
[optional] (logical) If TRUE, the matched
folders themselves will be deleted after their contents are removed.
Default is FALSE.
[optional] (logical) If TRUE, messages will be printed
about cleanup actions. Default is TRUE.