Learn R Programming

geeLite (version 1.0.6)

ee_as_tidyee: Minimal Replacement for tidyrgee::as_tidyee

Description

Creates a lightweight representation of an Earth Engine ee$ImageCollection, containing the original collection and its associated dates extracted from system:time_start.

Usage

ee_as_tidyee(ic)

Value

A list with:

ee_ob (the original ImageCollection) and

vrt (list containing a date vector).

Arguments

ic

[mandatory] (ee$ImageCollection) The Earth Engine image collection to convert.